==> apache-cxf-3.2.4-src.zip: apache-cxf-3.2.4-src/tools/javato/ws/src/test/java/org/apache/cxf/tools/java2wsdl/processor/FrontendFactoryTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.tools.java2wsdl.processor;


import org.apache.cxf.tools.fortest.classnoanno.docbare.Stock;
import org.apache.cxf.tools.fortest.simple.Hello;

import org.junit.Assert;
import org.junit.Test;

public class FrontendFactoryTest extends Assert {

    FrontendFactory factory = FrontendFactory.getInstance();

    @Test
    public void testDefaultStyle() {
        factory.setServiceClass(null);
        assertEquals(FrontendFactory.Style.Jaxws, factory.discoverStyle());
    }

    @Test
    public void testJaxwsStyle() {
        factory.setServiceClass(Stock.class);
        assertEquals(FrontendFactory.Style.Jaxws, factory.discoverStyle());
    }

    @Test
    public void testSimpleStyle() {
        factory.setServiceClass(Hello.class);
        assertEquals(FrontendFactory.Style.Simple, factory.discoverStyle());
    }
}

==> apache-cxf-4.1.2-src.zip: apache-cxf-4.1.2-src/tools/javato/ws/src/test/java/org/apache/cxf/tools/java2wsdl/processor/FrontendFactoryTest.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.tools.java2wsdl.processor;


import org.apache.cxf.tools.fortest.classnoanno.docbare.Stock;
import org.apache.cxf.tools.fortest.simple.Hello;

import org.junit.Test;

import static org.junit.Assert.assertEquals;

public class FrontendFactoryTest {

    FrontendFactory factory = FrontendFactory.getInstance();

    @Test
    public void testDefaultStyle() {
        factory.setServiceClass(null);
        assertEquals(FrontendFactory.Style.Jaxws, factory.discoverStyle());
    }

    @Test
    public void testJaxwsStyle() {
        factory.setServiceClass(Stock.class);
        assertEquals(FrontendFactory.Style.Jaxws, factory.discoverStyle());
    }

    @Test
    public void testSimpleStyle() {
        factory.setServiceClass(Hello.class);
        assertEquals(FrontendFactory.Style.Simple, factory.discoverStyle());
    }
}
